==> wink-lexicon-2.0.1.tgz: package/src/punctuations.js <==
//     wink-lexicon
//     English lexicon useful in NLP/NLU
//
//     Copyright (C) 2017-18  GRAYPE Systems Private Limited
//
//     This file is part of “wink-lexicon”.
//
//     Permission is hereby granted, free of charge, to any person obtaining a
//     copy of this software and associated documentation files (the "Software"),
//     to deal in the Software without restriction, including without limitation
//     the rights to use, copy, modify, merge, publish, distribute, sublicense,
//     and/or sell copies of the Software, and to permit persons to whom the
//     Software is furnished to do so, subject to the following conditions:
//
//     The above copyright notice and this permission notice shall be included
//     in all copies or substantial portions of the Software.
//
//     THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//     FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//     DEALINGS IN THE SOFTWARE.

//
// POS for punctuations.
/** @private */
var punctuationPOS = Object.create( null );
punctuationPOS[ '.' ] = '.';
punctuationPOS[ '!' ] = '.';
punctuationPOS[ '?' ] = '.';
punctuationPOS[ '[' ] = '(';
punctuationPOS[ '{' ] = '(';
punctuationPOS[ '(' ] = '(';
punctuationPOS[ ']' ] = ')';
punctuationPOS[ '}' ] = ')';
punctuationPOS[ ')' ] = ')';
punctuationPOS[ ',' ] = ',';
punctuationPOS[ ':' ] = ':';
punctuationPOS[ ';' ] = ':';
punctuationPOS[ '-' ] = ':';
punctuationPOS[ '…' ] = ':';
punctuationPOS[ '"' ] = '"';
punctuationPOS[ '\'' ] = '"';

module.exports = punctuationPOS;

==> wink-lexicon-2.1.1.tgz: package/src/punctuations.js <==
//     wink-lexicon
//     English lexicon useful in NLP/NLU
//
//     Copyright (C) 2017-19  GRAYPE Systems Private Limited
//
//     This file is part of “wink-lexicon”.
//
//     Permission is hereby granted, free of charge, to any person obtaining a
//     copy of this software and associated documentation files (the "Software"),
//     to deal in the Software without restriction, including without limitation
//     the rights to use, copy, modify, merge, publish, distribute, sublicense,
//     and/or sell copies of the Software, and to permit persons to whom the
//     Software is furnished to do so, subject to the following conditions:
//
//     The above copyright notice and this permission notice shall be included
//     in all copies or substantial portions of the Software.
//
//     THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//     FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//     DEALINGS IN THE SOFTWARE.

//
// POS for punctuations.
/** @private */
var punctuationPOS = Object.create( null );
punctuationPOS[ '.' ] = '.';
punctuationPOS[ '!' ] = '.';
punctuationPOS[ '?' ] = '.';
punctuationPOS[ '[' ] = '-LRB-';
punctuationPOS[ '{' ] = '-LRB-';
punctuationPOS[ '(' ] = '-LRB-';
punctuationPOS[ ']' ] = '-RRB-';
punctuationPOS[ '}' ] = '-RRB-';
punctuationPOS[ ')' ] = '-RRB-';
punctuationPOS[ ',' ] = ',';
punctuationPOS[ ':' ] = ':';
punctuationPOS[ ';' ] = ':';
punctuationPOS[ '--' ] = ':';
punctuationPOS[ '-' ] = 'HYPH';
punctuationPOS[ '…' ] = ':';
punctuationPOS[ '...' ] = ':';
punctuationPOS[ '"' ] = '"';
punctuationPOS[ '\'' ] = '"';

module.exports = punctuationPOS;
